# Sphinx VHS

Sphinx-VHS is an integration plugin for Sphinx and [VHS],
a tool by [charm] that renders terminal commands into GIFs.
It allows referencing ``.tape`` files form your docs,
and rendering them during sphinx build.

[VHS]: https://github.com/charmbracelet/vhs
[charm]: https://charm.sh/

## Resources

- [Documentation](https://taminomara.github.io/sphinx-vhs/)
- [Issues](https://github.com/taminomara/sphinx-vhs/issues/)
- [Source](https://github.com/taminomara/sphinx-vhs/)
- [PyPi](https://pypi.org/project/sphinx-vhs/)
- [Changelog](https://github.com/taminomara/sphinx-vhs/blob/main/CHANGELOG.md)
